<?php
/**
 * Retrieves and creates the wp-config.php file.
 *
 * The permissions for the base directory must allow for writing files in order
 * for the wp-config.php to be created using this page.
 *
 * @package WordPress
 * @subpackage Administration
 */

/**
 * We are installing.
 *
 * @package WordPress
 */
define('WP_INSTALLING', true);

/**#@+
 * These three defines are required to allow us to use require_wp_db() to load
 * the database class while being wp-content/db.php aware.
 * @ignore
 */
define('ABSPATH', dirname(dirname(__FILE__)).'/');
define('WPINC', 'wp-includes');
define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
/**#@-*/

require_once(ABSPATH . WPINC . '/compat.php');
require_once(ABSPATH . WPINC . '/functions.php');
require_once(ABSPATH . WPINC . '/classes.php');

if (!file_exists(ABSPATH . 'wp-config-sample.php'))
	wp_die('عذرا الملف wp-config-sample.php غير موجود يجب إعادة تحميل هذا الملف مرة أخرى من ملفات الووردبريس الأصلية');

$configFile = file(ABSPATH . 'wp-config-sample.php');

if ( !is_writable(ABSPATH))
	wp_die("عذرا، لا يمكن الكتابة إلى المجلد المحدد ، لا يوجد صلاحية كافية للكتابة إلى مجلد مدونة الرئيسي قم بتغير الصلاحيات أو إنشاء ملف wp-config.php يدوياً");

// Check if wp-config.php has been created
if (file_exists(ABSPATH . 'wp-config.php'))
	wp_die("<p>الملف 'wp-config.php' موجود مسبقا. لإعادة ضبط الإعدادات قم بحذف الملف أولا. أو جرب  <a href='install.php'>بدء تنصيب</a> الووردبريس الآن.</p>");

// Check if wp-config.php exists above the root directory but is not part of another install
if (file_exists(ABSPATH . '../wp-config.php') && ! file_exists(ABSPATH . '../wp-settings.php'))
	wp_die("<p>The file 'wp-config.php' already exists one level above your WordPress installation. If you need to reset any of the configuration items in this file, please delete it first. You may try <a href='install.php'>installing now</a>.</p>");

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

/**
 * Display setup wp-config.php file header.
 *
 * @ignore
 * @since 2.3.0
 * @package WordPress
 * @subpackage Installer_WP_Config
 */
function display_header() {
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>ووردبريس &rsaquo; ضبط ملف الإعدادات</title>
<link rel="stylesheet" href="css/install.css" type="text/css" />

</head>
<body>
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>

<p>أهلا بك في مدونة الووردبريس. قبل البدء في إعداد المدونة نحتاج المعلومات التالية عن قاعدة البيانات:</p>
<ol>
	<li>اسم قاعدة البيانات</li>
	<li>اسم المستخدم لقاعدة البيانات</li>
	<li>كلمة المرور</li>
	<li>اسم المستضيف لقاعدة البيانات</li>
	<li>بادئة الجداول (مطلوبة في حال رغبت في تركيب أكثر من مدونة في نفس قاعدة البيانات)</li>
</ol>
<p><strong>لأي سبب من الأسباب لم يتم إنشاء ملف الإعدادات تلقائيا بإمكانك ببساطة فتح الملف  <code>wp-config-sample.php</code> ووضع الإعدادات السابقة يدويا ومن ثم حفظ الملف مرة أخرى باسم <code>wp-config.php</code> ورفعه إلى الدليل الرئيسي للمدونة. </strong></p>
<p> عادة يتم توفير البيانات السابقة من الشركة المستضيفة لموقعك في حال عدم توفر تلك المعلومات لديك فيمكنك التواصل مع المستضيف والإستفسار عن ذلك.</p>

<p class="step"><a href="setup-config.php?step=1" class="button">متابعة</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
<form method="post" action="setup-config.php?step=2">
	<p>أدخل بيانات الإتصال بقاعدة البيانات، يمكنك الإتصال بالشركة المستضيفة لموقعك للإستفسار عن هذه البيانات. </p>
	<table class="form-table">
		<tr>
			<th scope="row"><label for="dbname">اسم قاعدة البيانات</label></th>
			<td><input name="dbname" id="dbname" type="text" size="25" value="wordpress" /></td>
			<td>اسم قاعدة البيانات التي ستعمل عليها مدونة الووردبريس</td>
		</tr>
		<tr>
			<th scope="row"><label for="uname">اسم المستخدم</label></th>
			<td><input name="uname" id="uname" type="text" size="25" value="username" /></td>
			<td>اسم المستخدم لـ(MySQL)</td>
		</tr>
		<tr>
			<th scope="row"><label for="pwd">كلمة المرور</label></th>
			<td><input name="pwd" id="pwd" type="text" size="25" value="password" /></td>
			<td>كلمة المرور لـ (MySQL)</td>
		</tr>
		<tr>
			<th scope="row"><label for="dbhost">اسم المستضيف</label></th>
			<td><input name="dbhost" id="dbhost" type="text" size="25" value="localhost" /></td>
			<td>بنسبة 99% لن تحتاج تغيير هذه القيمة.</td>
		</tr>
		<tr>
			<th scope="row"><label for="prefix">بادئة الجداول</label></th>
			<td><input name="prefix" id="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
			<td>إذا كنت ترغب في تشغيل أكثر من مدونة ورردبريس في نفس قاعدة البيانات قم بتغيير هذه القيمة</td>
		</tr>
	</table>
	<p class="step"><input name="submit" type="submit" value="إرســال" class="button" /></p>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if (empty($prefix)) $prefix = 'wp_';

	// Test the db connection.
	/**#@+
	 * @ignore
	 */
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);
	/**#@-*/

	// We'll fail here if the values are no good.
	require_wp_db();
	if ( !empty($wpdb->error) )
		wp_die($wpdb->error->get_error_message());

	$handle = fopen(ABSPATH . 'wp-config.php', 'w');

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				fwrite($handle, str_replace("putyourdbnamehere", $dbname, $line));
				break;
			case "define('DB_USER'":
				fwrite($handle, str_replace("'usernamehere'", "'$uname'", $line));
				break;
			case "define('DB_PASSW":
				fwrite($handle, str_replace("'yourpasswordhere'", "'$passwrd'", $line));
				break;
			case "define('DB_HOST'":
				fwrite($handle, str_replace("localhost", $dbhost, $line));
				break;
			case '$table_prefix  =':
				fwrite($handle, str_replace('wp_', $prefix, $line));
				break;
			default:
				fwrite($handle, $line);
		}
	}
	fclose($handle);
	chmod(ABSPATH . 'wp-config.php', 0666);

	display_header();
?>
<p>لقد تم الآن تكوين الجزء المتعلق بالإتصال بقاعدة البيانات، إبدأ الآن في تنصيب الورردبريس.</p>

<p class="step"><a href="install.php" class="button">تنصيب الووردبريس</a></p>
<?php
	break;
}
?>
</body>
</html>
